"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetadataTransformerFactory = void 0;
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const errors_1 = require("../../errors");
const convertContext_1 = require("../convertContext");
const defaultMetadataTransformer_1 = require("./defaultMetadataTransformer");
const decomposedMetadataTransformer_1 = require("./decomposedMetadataTransformer");
const staticResourceMetadataTransformer_1 = require("./staticResourceMetadataTransformer");
const nonDecomposedMetadataTransformer_1 = require("./nonDecomposedMetadataTransformer");
class MetadataTransformerFactory {
    constructor(registry, context = new convertContext_1.ConvertContext()) {
        this.registry = registry;
        this.context = context;
    }
    getTransformer(component) {
        var _a;
        // transformer is determined by the parent, if the component has one
        const type = component.parent ? component.parent.type : component.type;
        const transformerId = (_a = type.strategies) === null || _a === void 0 ? void 0 : _a.transformer;
        switch (transformerId) {
            case "standard" /* Standard */:
            case undefined:
                return new defaultMetadataTransformer_1.DefaultMetadataTransformer(this.registry, this.context);
            case "decomposed" /* Decomposed */:
                return new decomposedMetadataTransformer_1.DecomposedMetadataTransformer(this.registry, this.context);
            case "staticResource" /* StaticResource */:
                return new staticResourceMetadataTransformer_1.StaticResourceMetadataTransformer(this.registry, this.context);
            case "nonDecomposed" /* NonDecomposed */:
                return new nonDecomposedMetadataTransformer_1.NonDecomposedMetadataTransformer(this.registry, this.context);
            default:
                throw new errors_1.RegistryError('error_missing_transformer', [type.name, transformerId]);
        }
    }
}
exports.MetadataTransformerFactory = MetadataTransformerFactory;
//# sourceMappingURL=metadataTransformerFactory.js.map